@@ -41,6 +41,7 @@ class QIcon;
 
 namespace Okular {
 
+class BackendOpaqueAction;
 class DocumentFonts;
 class DocumentInfo;
 class DocumentObserver;
@@ -213,7 +214,7 @@ class OKULARCORE_EXPORT Generator : public QObject
         /**
          * Creates a new generator.
          */
-        Generator(QObject* parent = Q_NULLPTR, const QVariantList& args = QVariantList());
+        Generator(QObject* parent = nullptr, const QVariantList& args = QVariantList());
 
         /**
          * Destroys the generator.
@@ -440,6 +441,11 @@ class OKULARCORE_EXPORT Generator : public QObject
          */
         virtual QAbstractItemModel * layersModel() const;
 
+        /**
+         * Calls the backend to execute an BackendOpaqueAction
+         */
+        virtual void opaqueAction( const BackendOpaqueAction *action );
+
     Q_SIGNALS:
         /**
          * This signal should be emitted whenever an error occurred in the generator.
@@ -512,11 +518,29 @@ class OKULARCORE_EXPORT Generator : public QObject
          */
         void setFeature( GeneratorFeature feature, bool on = true );
 
+        /**
+         * Internal document setting
+         */
+        enum DocumentMetaDataKey {
+            PaperColorMetaData,         ///< Returns (QColor) the paper color if set in Settings or the default color (white) if option is true (otherwise returns a non initialized QColor)
+            TextAntialiasMetaData,      ///< Returns (bool) text antialias from Settings (option is not used)
+            GraphicsAntialiasMetaData,  ///< Returns (bool)graphic antialias from Settings (option is not used)
+            TextHintingMetaData         ///< Returns (bool)text hinting from Settings (option is not used)
+        };
+
+        /**
+         * Request a meta data of the Document, if available, like an internal
+         * setting.
+         *
+         * @since 1.1
+         */
+        QVariant documentMetaData( const DocumentMetaDataKey key, const QVariant &option = QVariant() ) const;
+
         /**
          * Request a meta data of the Document, if available, like an internal
          * setting.
          */
-        QVariant documentMetaData( const QString &key, const QVariant &option = QVariant() ) const;
+        OKULARCORE_DEPRECATED QVariant documentMetaData( const QString &key, const QVariant &option = QVariant() ) const;
 
         /**
          * Return the pointer to a mutex the generator can use freely.
