@@ -29,17 +29,17 @@ class AnnotationModel : public QAbstractItemModel
             PageRole
         };
 
-        explicit AnnotationModel( Okular::Document *document, QObject *parent = Q_NULLPTR );
+        explicit AnnotationModel( Okular::Document *document, QObject *parent = nullptr );
         virtual ~AnnotationModel();
 
         // reimplementations from QAbstractItemModel
-        int columnCount( const QModelIndex &parent = QModelIndex() ) const Q_DECL_OVERRIDE;
-        QVariant data( const QModelIndex &index, int role = Qt::DisplayRole ) const Q_DECL_OVERRIDE;
-        bool hasChildren( const QModelIndex &parent = QModelIndex() ) const Q_DECL_OVERRIDE;
-        QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const Q_DECL_OVERRIDE;
-        QModelIndex index( int row, int column, const QModelIndex &parent = QModelIndex() ) const Q_DECL_OVERRIDE;
-        QModelIndex parent( const QModelIndex &index ) const Q_DECL_OVERRIDE;
-        int rowCount( const QModelIndex &parent = QModelIndex() ) const Q_DECL_OVERRIDE;
+        int columnCount( const QModelIndex &parent = QModelIndex() ) const override;
+        QVariant data( const QModelIndex &index, int role = Qt::DisplayRole ) const override;
+        bool hasChildren( const QModelIndex &parent = QModelIndex() ) const override;
+        QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const override;
+        QModelIndex index( int row, int column, const QModelIndex &parent = QModelIndex() ) const override;
+        QModelIndex parent( const QModelIndex &index ) const override;
+        int rowCount( const QModelIndex &parent = QModelIndex() ) const override;
 
         bool isAnnotation( const QModelIndex &index ) const;
         Okular::Annotation* annotationForIndex( const QModelIndex &index ) const;
