@@ -28,7 +28,7 @@ SearchLineEdit::SearchLineEdit( QWidget * parent, Okular::Document * document )
       m_caseSensitivity( Qt::CaseInsensitive ),
       m_searchType( Okular::Document::AllDocument ), m_id( -1 ),
       m_moveViewport( false ), m_changed( false ), m_fromStart( true ),
-      m_searchRunning( false )
+      m_findAsYouType( true ), m_searchRunning( false )
 {
     setObjectName( QStringLiteral( "SearchLineEdit" ) );
     setClearButtonShown( true );
@@ -100,6 +100,11 @@ void SearchLineEdit::setSearchFromStart( bool fromStart )
     m_fromStart = fromStart;
 }
 
+void SearchLineEdit::setFindAsYouType( bool findAsYouType )
+{
+    m_findAsYouType = findAsYouType;
+}
+
 void SearchLineEdit::resetSearch()
 {
     // Stop the currently running search, if any
@@ -175,7 +180,11 @@ void SearchLineEdit::slotTextChanged( const QString & text )
     Q_UNUSED(text);
 
     prepareLineEditForSearch();
-    restartSearch();
+
+    if ( m_findAsYouType )
+        restartSearch();
+    else
+        m_changed = true;
 }
 
 void SearchLineEdit::prepareLineEditForSearch()
